# FiscalSim US

[![CGO cataloged](https://img.shields.io/badge/CGO-catalogued-9cf)](https://github.com/TheCGO)
[![Python 3.9](https://img.shields.io/badge/python-3.9-blue.svg)](https://www.python.org/downloads/release/python-3916/)
![example event parameter](https://github.com/TheCGO/fiscalsim-us/actions/workflows/push.yaml/badge.svg?branch=main)
[![Codecov](https://codecov.io/gh/TheCGO/fiscalsim-us/branch/main/graph/badge.svg)](https://codecov.io/gh/TheCGO/fiscalsim-us)

FiscalSim US is an open source microsimulation model of the US federal and state household tax and benefit system. It is supported and maintained by [The Center for Growth and Opportunity at Utah State University (CGO)](https://www.thecgo.org/). Much of the original federal tax and benefit code and some of the state tax logic was developed by [PolicyEngine](https://policyengine.org/), with which CGO originally had a partnership. Their US model is at [https://github.com/PolicyEngine/policyengine-us](https://github.com/PolicyEngine/policyengine-us).
